==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/pt_BR.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contatos",
"Save" => "Guardar",
"Uploading..." => "Enviando...",
"Importing..." => "Importando...",
"Preparing..." => "Preparando...",
"Imported {count} of {total} contacts" => "Importado {count} de {total} contatos",
"Imported {imported} contacts. {failed} failed." => "Importado {imported} contatos. {failed} falhou.",
"An address book called {name} already exists" => "Um livro de endereços chamado {name} já existe",
"Failed adding address book: {error}" => "Falha na adição ao livro de endereços: {error}",
"Failed loading address books: {error}" => "Falha no carregamento do livro de endereços: {error}",
"Indexing contacts" => "Indexando contatos",
"Unrecoverable error loading address books: {msg}" => "Erro irrecuperável carregando o livros de endereços: {msg}",
"Error." => "Erro.",
"Add to..." => "Adicionar a...",
"Remove from..." => "Remover de...",
"Add group..." => "Adicionar grupo...",
"Invalid URL: \"{url}\"" => "URL inválida:\"{url}\"",
"There was an error opening a mail composer." => "Houve um erro ao abrir um editor de correio.",
"Invalid email: \"{url}\"" => "Email inválido:\"{url}\"",
"Merge failed. Cannot find contact: {id}" => "A mesclagem falhou. Não foi possível encontrar o contato: {id}",
"Merge failed." => "A mesclagem falhou.",
"Merge failed. Error saving contact." => "A mesclagem falhou. Erro salvando o contato.",
"Select photo" => "Selecione foto",
"Network or server error. Please inform administrator." => "Erro no servidor ou rede. Por favor, informe o administrador.",
"Error adding to group." => "Erro ao adicionar ao grupo.",
"Error removing from group." => "Erro ao remover do grupo.",
"Error setting {name} as favorite." => "Erro configurando {name} como favorito.",
"Merge contacts" => "Mesclar contatos",
"Cancel" => "Cancelar",
"Add group" => "Adicionar grupo",
"OK" => "OK",
"Could not find contact: {id}" => "Não foi possível encontrar o contato:{id}",
"No files selected for upload." => "Nenhum arquivo selecionado para carregar.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "O arquivo que você está tentando carregar excede o tamanho máximo para este servidor.",
"Edit profile picture" => "Editar imagem do perfil",
"Crop photo" => "Recortar foto",
"Is this correct?" => "Isto está certo?",
"Error parsing date: {date}" => "Erro na data de análise: {data}",
"# groups" => "# grupos",
"Error parsing birthday {bday}: {error}" => "Erro passando data do aniversário {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alguns contatos foram marcados para remoção, mas não foram removidos ainda. Por favor aguarde a remoção desses contatos.",
"Click to undo deletion of {num} contacts" => "Clique para desfazer a exclusão de {num} contatos",
"Cancelled deletion of {num} contacts" => "Cancelada a eliminação de {num} contatos",
"Add" => "Adicionar",
"Contact is already in this group." => "O contato já pertence ao grupo.",
"Contacts are already in this group." => "Os contatos já pertencem ao grupo.",
"Couldn't get contact list." => "Não foi possível obter lista de contatos.",
"Contact is not in this group." => "O contato não está neste grupo.",
"Contacts are not in this group." => "Os contatos não estão neste grupo.",
"Failed renaming group: {error}" => "Falha renomeando grupo:{error}",
"A group named {group} already exists" => "Já existe um grupo com o nome {group}",
"You can drag groups to\narrange them as you like." => "Você pode arrastar grupos\npara ordená-los como quiser.",
"Failed adding group: {error}" => "Falha adicionando grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Compartilhado por {owner}",
"Not grouped" => "Não agrupado",
"Failed loading groups: {error}" => "Falha carregando grupos:{error}",
"Please choose the addressbook" => "Por favor, selecione uma agenda de endereços",
"Import into..." => "Importando...",
"Error loading import template" => "Erro carregando a importação de modelo",
"Import contacts" => "Importar contatos",
"Import" => "Importar",
"Import done" => "Importação concluída",
"Close" => "Fechar",
"Error" => "Erro",
"Displayname cannot be empty." => "Nome de exibição não pode ficar em branco.",
"Show CardDav link" => "Mostrar link CardDav",
"Show read-only VCF link" => "Mostrar link VCF somente-leitura",
"Download" => "Baixar",
"Edit" => "Editar",
"Delete" => "Excluir",
"More..." => "Mais...",
"Less..." => "Menos...",
"Server error! Please inform system administator" => "Erro no servidor. Por favor, informe o administrador.",
"Failed loading photo: {error}" => "Falha carregando foto: {error}",
"You do not have permissions to see this contacts" => "Você não tem permissão para ver este contatos",
"Contact not found" => "Contato não encontrado",
"You do not have permissions to see these contacts" => "Você não tem permissão para ver esses contatos",
"You do not have permissions add contacts to the address book" => "Você não tem permissão para adicionar contatos no catálogo de endereços",
"The backend for this address book does not support adding contacts" => "O final deste catálogo de endereços não suporta a adição de contatos",
"You do not have permissions to delete this contact" => "Você não tem permissão para excluir esse contato",
"The backend for this address book does not support deleting contacts" => "O final deste catálogo de endereços não suporta a exclusão de contatos",
"Unknown error" => "Erro desconhecido",
"The backend for this address book does not support updating" => "O final deste catálogo de endereços não suporta a atualização",
"You don't have permissions to update the address book." => "Você não tem permissão para atualizar o catálogo de endereços.",
"You don't have permissions to delete the address book." => "Você não tem permissões para excluir o livro de endereços.",
"Address book not found" => "Nenhum livro de endereço encontrado",
"You do not have permissions to see this contact" => "Você não tem permissão para ver este contato",
"You do not have permissions to update this contact" => "Você não tem permissão para atualizar esse contato",
"The backend for this contact does not support updating it" => "O final deste contato não suporta atualização",
"This backend not support adding contacts" => "Este final não suporta adicionar contatos",
"Property not found" => "Propriedade não encontrada",
" Missing IM parameter for: " => "Falta parâmetro IM para:",
"Unknown IM: " => "IM desconhecido:",
"{name}'s Birthday" => "Aniversário de {name}",
"Error creating address book" => "Erro criando livro de endereço",
"Error updating address book" => "Erro atualizando o livro de endereço",
"You do not have permissions to delete the \"%s\" address book" => "Você não tem permissão para excluir o livro de endereços \"%s\"",
"Error deleting address book" => "Erro excluindo livro de endereço",
"Error creating contact." => "Erro criando contato.",
"Error deleting contact." => "Erro excluindo conato.",
"Error retrieving contact." => "Erro recuperando contato.",
"Error saving contact." => "Erro ao salvar contato.",
"Error removing contact from other address book." => "Erro removendo contato de outro livro de endereço.",
"Couldn't find contact." => "Não foi possível encontrar o contato.",
"No contact data in request." => "Não há dados de contato no pedido.",
"Error merging into contact." => "Erro mesclando contato.",
"Error saving contact to backend." => "Erro salvando contato no final.",
"Property name is not set." => "Nome da propriedade não está definida.",
"Property checksum is not set." => "Verificação de propriedade não está definida.",
"Information about vCard is incorrect. Please reload the page." => "Informações sobre vCard é incorreta. Por favor, recarregue a página.",
"Error updating contact" => "Erro ao atualizar o contato",
"Error saving contact to backend" => "Erro salvando contato no final.",
"Error getting user photo" => "Erro obtendo a foto do usuário",
"No file was uploaded. Unknown error" => "Nenhum arquivo foi enviado. Erro desconhecido",
"There is no error, the file uploaded with success" => "Sem erros, o arquivo foi enviado com sucesso",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O arquivo enviado excede a diretiva upload_max_filesize em php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O arquivo carregado excede o argumento MAX_FILE_SIZE especificado no formulário HTML",
"The uploaded file was only partially uploaded" => "O arquivo foi parcialmente enviado",
"No file was uploaded" => "Nenhum arquivo enviado",
"Missing a temporary folder" => "Pasta temporária não encontrada",
"Couldn't load temporary image: " => "Não foi possível carregar a imagem temporária:",
"Couldn't save temporary image: " => "Não foi possível salvar a imagem temporária:",
"No photo path was submitted." => "Nenhum caminho para foto foi submetido.",
"File doesn't exist:" => "Arquivo não existe:",
"Error loading image." => "Erro ao carregar imagem.",
"Image has been removed from cache" => "Imagem foi removida do cache",
"Error creating temporary image" => "Erro ao criar imagem temporária",
"Error cropping image" => "Erro ao recortar imagem",
"Error resizing image" => "Erro ao modificar tamanho da imagem",
"Error getting PHOTO property." => "Erro ao obter propriedade da FOTO.",
"No group name given." => "Nenhum nome de grupo foi fornecido.",
"Error adding group." => "Erro ao adicionar grupo.",
"No group name to rename from given." => "Nenhum nome de grupo para renomear foi fornecido.",
"No group name to rename to given." => "Nenhum nome de grupo para renomear foi fornecido.",
"Error renaming group." => "Erro renomeando grupo.",
"Group ID missing from request." => "O ID do grupo requisitado não foi encontrado.",
"Group name missing from request." => "Nome do grupo ausente da requisição.",
"Contact ID missing from request." => "O ID do contato requisitado não foi encontrado.",
"Failed to write to disk" => "Falha ao escrever no disco",
"Not enough storage available" => "Espaço de armazenamento insuficiente",
"Attempt to upload blacklisted file:" => "Tente fazer o envio do arquivo de lista negra:",
"Error uploading contacts to storage." => "Erro enviando contatos para armazenamento.",
"Error moving file to imports folder." => "Erro ao mover arquivo para a pasta de importações.",
"You do not have permissions to import into this address book." => "Você não tem permissão para importar para este livro de endereços.",
"File name missing from request." => "Nome do arquivo ausente da requisção.",
"Progress key missing from request." => "Chave de progresso faltando no pedido.",
"Attempt to access blacklisted file:" => "Tentando acessar o arquivo de lista negra:",
"No contacts found in: " => "Nenhum contato encontrado em:",
"No key is given." => "Nenhuma chave foi fornecida.",
"No value is given." => "Nenhum valor foi fornecido.",
"Could not set preference: " => "Não foi possível definir preferência:",
"Contact" => "Contato",
"Other" => "Outro",
"HomePage" => "Página Inicial",
"Jabber" => "Jabber",
"Internet call" => "Chamada da Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Trabalho",
"Home" => "Home",
"Mobile" => "Móvel",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensagem",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Família",
"New Contact" => "Novo Contato",
"Group name" => "Nome do grupo",
"New Group" => "Novo Grupo",
"Address books" => "Livros de Endereços",
"Display name" => "Nome de exibição",
"Add Address Book" => "Adicionar Livro de Endereço",
"Select file..." => "Selecionar arquivo...",
"(De-)select all" => "(Des)selecionar tudo",
"Sort order" => "Ordenar",
"First- Lastname" => "Nome- Sobrenome",
"Last-, Firstname" => "Sobrenome-, Nome",
"Groups" => "Grupos",
"Favorite" => "Favorito",
"Merge selected" => "Mesclar selecionado",
"Keyboard shortcuts" => "Atalhos do teclado",
"Navigation" => "Navegação",
"Next contact in list" => "Próximo contato na lista",
"Previous contact in list" => "Contato anterior na lista",
"Expand/collapse current addressbook" => "Expandir/recolher agenda atual",
"Next addressbook" => "Próxima agenda",
"Previous addressbook" => "Agenda anterior",
"Actions" => "Ações",
"Refresh contacts list" => "Atualizar lista de contatos",
"Add new contact" => "Adicionar novo contato",
"Add new addressbook" => "Adicionar nova agenda",
"Delete current contact" => "Remover contato atual",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Você não possui contatos na agenda.</h3><p>Adicione um novo contato ou importe contatos existentes de um arquivo VCF.</p>",
"Add contact" => "Adicionar contatos",
"Delete group" => "Excluir grupo",
"Rename group" => "Renomear grupo",
"Which contact should the data be merged into?" => "Quais os dados de contato que devem ser incorporados?",
"Delete the other(s) after successful merge?" => "Eliminar os outros após o sucesso da mesclagem?",
"Compose mail" => "Escrever e-mail",
"Delete current photo" => "Deletar imagem atual",
"Edit current photo" => "Editar imagem atual",
"Upload new photo" => "Carregar nova foto",
"Select photo from ownCloud" => "Selecionar foto do OwnCloud",
"Name" => "Nome",
"First name" => "Primeiro nome",
"Additional names" => "Segundo Nome",
"Last name" => "Sobrenome",
"Select groups" => "Selecionar grupos",
"Select address book" => "Selecionar livro de endereços",
"Nickname" => "Apelido",
"Enter nickname" => "Digite o apelido",
"Title" => "Título",
"Enter title" => "Insira o título",
"Organization" => "Organização",
"Enter organization" => "Insira a organização",
"Birthday" => "Aniversário",
"Notes go here..." => "Observações aqui...",
"Export as VCF" => "Exportar como VCF",
"Add field..." => "Adicionar um campo...",
"Phone" => "Telefone",
"Email" => "E-mail",
"Instant Messaging" => "Mensagem Instantânea",
"Address" => "Endereço",
"Note" => "Nota",
"Web site" => "Web site",
"Delete contact" => "Apagar contato",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor, especifique um email válido.",
"someone@example.com" => "alguem@exemplo.com",
"Mail to address" => "Correio para endereço",
"Delete email address" => "Remover endereço de email",
"Enter phone number" => "Digite um número de telefone",
"Delete phone number" => "Remover número de telefone",
"Go to web site" => "Ir para web site",
"Delete URL" => "Excluir URL",
"View on map" => "Visualizar no mapa",
"Delete address" => "Excluir endereço",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Endereço da rua",
"20500" => "20500",
"Postal code" => "Código postal",
"Washington, DC" => "Washington, DC",
"City" => "Cidade",
"District of Columbia" => "District of Columbia",
"State or province" => "Estado ou província",
"USA" => "USA",
"Country" => "País",
"Instant Messenger" => "Mensageiro Instantâneo",
"Delete IM" => "Delete IM",
"Active" => "Ativo",
"Share" => "Compartilhar",
"Export" => "Exportar",
"CardDAV link" => "Link CardDAV",
"CardDAV syncing addresses" => "Sincronizando endereços CardDAV",
"more info" => "mais informações",
"Primary address (Kontact et al)" => "Endereço primário (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Agendas de Endereço",
"New Address Book" => "Nova agenda",
"Description" => "Descrição"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/pt_BR.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contatos",
"Add new LDAP Addressbook" => "Adicionar novos endereços LDAP ",
"Ok" => "Ok",
"Cancel" => "Cancelar",
"Save" => "Salvar",
"Edit Addressbook" => "Editar Agenda de Endereço",
"Starting file import" => "Iniciando importação de arquivos",
"Format selected: {format}" => "Formato selecionado: {format}",
"Automatic format detection" => "Detecção automática de formato",
"Processing {count}/{total} cards" => "Processando {count}/{total} cartões",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total},  Sucesso:{imported}, Erros:{failed}",
"An address book called {name} already exists" => "Um livro de endereços chamado {name} já existe",
"Failed adding address book: {error}" => "Falha na adição ao livro de endereços: {error}",
"Failed loading address books: {error}" => "Falha no carregamento do livro de endereços: {error}",
"Server error! Please inform system administator" => "Erro no servidor. Por favor, informe o administrador.",
"Indexing contacts" => "Indexando contatos",
"Unrecoverable error loading address books: {msg}" => "Erro irrecuperável carregando o livros de endereços: {msg}",
"Error." => "Erro.",
"Add to..." => "Adicionar a...",
"Remove from..." => "Remover de...",
"Add group..." => "Adicionar grupo...",
"Invalid URL: \"{url}\"" => "URL inválida:\"{url}\"",
"Invalid email: \"{url}\"" => "Email inválido:\"{url}\"",
"Merge failed. Cannot find contact: {id}" => "A mesclagem falhou. Não foi possível encontrar o contato: {id}",
"Merge failed." => "A mesclagem falhou.",
"Merge failed. Error saving contact." => "A mesclagem falhou. Erro salvando o contato.",
"Select photo" => "Selecione foto",
"Network or server error. Please inform administrator." => "Erro no servidor ou rede. Por favor, informe o administrador.",
"Only images can be used as contact photos" => "Apenas as imagens podem ser utilizadas como fotos de contato",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "O tamanho de \"{filename}\" excede o máximo permitido {size}",
"Error adding to group." => "Erro ao adicionar ao grupo.",
"Error removing from group." => "Erro ao remover do grupo.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Você selecionou mais de 300 contatos.\nIsso provavelmente irá falhar! Clique aqui para tentar de qualquer maneira.",
"Error setting {name} as favorite." => "Erro configurando {name} como favorito.",
"Merge contacts" => "Mesclar contatos",
"Add group" => "Adicionar grupo",
"OK" => "OK",
"Could not find contact: {id}" => "Não foi possível encontrar o contato: {id}",
"Edit profile picture" => "Editar imagem do perfil",
"Crop photo" => "Recortar foto",
"Error parsing date: {date}" => "Erro na data de análise: {data}",
"# groups" => "# grupos",
"Error parsing birthday {bday}" => "Erro na análise da data de aniversário {bday}",
"The backend does not support multi-byte characters." => "O backend não suporta caracteres multi-byte.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alguns contatos foram marcados para remoção, mas não foram removidos ainda. Por favor, aguarde a remoção desses contatos.",
"Click to undo deletion of {num} contacts" => "Clique para desfazer a exclusão de {num} contatos",
"Cancelled deletion of {num} contacts" => "Cancelada a eliminação de {num} contatos",
"Add" => "Adicionar",
"Contact is already in this group." => "O contato já pertence ao grupo.",
"Contacts are already in this group." => "Os contatos já pertencem ao grupo.",
"Couldn't get contact list." => "Não foi possível obter a lista de contatos.",
"Contact is not in this group." => "O contato não está neste grupo.",
"Contacts are not in this group." => "Os contatos não estão neste grupo.",
"A group named \"{group}\" already exists" => "Um grupo chamado \"{group}\" já existe",
"Failed renaming group: {error}" => "Falha renomeando grupo:{error}",
"You can drag groups to\narrange them as you like." => "Você pode arrastar grupos\npara ordená-los como quiser.",
"Failed adding group: {error}" => "Falha adicionando grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Compartilhado por {owner}",
"Not grouped" => "Não agrupado",
"Failed loading groups: {error}" => "Falha carregando grupos: {error}",
"Please choose the addressbook" => "Por favor, selecione uma agenda de endereços",
"Import into..." => "Importando...",
"Error loading import template" => "Erro carregando a importação de modelo",
"Import contacts" => "Importar contatos",
"Import" => "Importar",
"Importing..." => "Importando...",
"Import done" => "Importação concluída",
"Close" => "Fechar",
"Error, missing parameters: " => "Erro, parâmetros que faltam:",
"Failed loading photo: {error}" => "Falha carregando foto: {error}",
"You do not have permissions to see this contact" => "Você não tem permissão para ver este contato",
"Contact not found" => "Contato não encontrado",
"You do not have permissions to see these contacts" => "Você não tem permissão para ver esses contatos",
"You do not have permissions add contacts to the address book" => "Você não tem permissão para adicionar contatos no catálogo de endereços",
"The backend for this address book does not support adding contacts" => "O final deste catálogo de endereços não suporta a adição de contatos",
"You do not have permissions to delete this contact" => "Você não tem permissão para excluir esse contato",
"The backend for this address book does not support deleting contacts" => "O final deste catálogo de endereços não suporta a exclusão de contatos",
"Unknown error" => "Erro desconhecido",
"Access denied" => "Acesso negado",
"The backend for this address book does not support updating" => "O final deste catálogo de endereços não suporta a atualização",
"You don't have permissions to delete the address book." => "Você não tem permissões para excluir o livro de endereços.",
"Address book not found" => "Nenhum livro de endereço encontrado",
"You do not have permissions to update this contact" => "Você não tem permissão para atualizar esse contato",
"The backend for this contact does not support updating it" => "O backend deste contato não suporta atualização",
"This backend does not support adding contacts" => "Este backend não suporta a adição de contatos",
"Property not found" => "Propriedade não encontrada",
" Missing IM parameter for: " => "Falta parâmetro IM para:",
"Unknown IM: " => "IM desconhecido:",
"{name}'s Birthday" => "Aniversário de {name}",
"Error creating address book" => "Erro criando livro de endereço",
"The \"%s\" backend does not support deleting address books" => "O backend \"%s\" não suporta apagar livros de endereços",
"You do not have permissions to delete the \"%s\" address book" => "Você não tem permissão para excluir o livro de endereços \"%s\"",
"Error deleting address book" => "Erro excluindo livro de endereço",
"Error creating contact." => "Erro criando contato.",
"Error creating contact" => "Erro criando contato",
"Error deleting contact" => "Erro eliminando contato",
"Error retrieving contact" => "Erro recuperando contato",
"Error saving contact" => "Erro salvando contato",
"Error removing contact from other address book." => "Erro removendo contato de outro livro de endereço.",
"Error getting moved contact" => "Erro movendo contato",
"Couldn't find contact." => "Não foi possível encontrar o contato.",
"No contact data in request." => "Não há dados de contato no pedido.",
"Error merging into contact." => "Erro mesclando contato.",
"Error saving contact to backend." => "Erro salvando contato no backend.",
"Property name is not set." => "Nome da propriedade não está definida.",
"Property checksum is not set." => "Verificação de propriedade não está definida.",
"Information about vCard is incorrect. Please reload the page." => "Informações sobre vCard é incorreta. Por favor, recarregue a página.",
"Error updating contact" => "Erro ao atualizar o contato",
"Error saving contact to backend" => "Erro salvando contato no backend.",
"Error getting user photo" => "Erro obtendo a foto do usuário",
"No photo path was submitted." => "Nenhum caminho para foto foi submetido.",
"Error loading image from cache" => "Erro ao carregar imagem a partir do cache",
"Error getting PHOTO property." => "Erro ao obter propriedade da FOTO.",
"Error saving contact." => "Erro ao salvar contato.",
"No group name given." => "Nenhum nome de grupo foi fornecido.",
"Error adding group." => "Erro ao adicionar grupo.",
"No group name to rename from given." => "Nenhum nome de grupo para renomear foi fornecido.",
"No group name to rename to given." => "Nenhum nome de grupo para renomear foi fornecido.",
"Error renaming group." => "Erro renomeando grupo.",
"Group ID missing from request." => "O ID do grupo requisitado não foi encontrado.",
"Group name missing from request." => "Nome do grupo ausente da requisição.",
"Contact ID missing from request." => "O ID do contato requisitado não foi encontrado.",
"No file was uploaded. Unknown error" => "Nenhum arquivo foi enviado. Erro desconhecido",
"There is no error, the file uploaded with success" => "Sem erros, o arquivo foi enviado com sucesso",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O arquivo enviado excede a diretiva upload_max_filesize em php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O arquivo carregado excede o argumento MAX_FILE_SIZE especificado no formulário HTML",
"The uploaded file was only partially uploaded" => "O arquivo foi somente parcialmente enviado",
"No file was uploaded" => "Nenhum arquivo enviado",
"Missing a temporary folder" => "Pasta temporária não encontrada",
"Failed to write to disk" => "Falha ao escrever no disco",
"Not enough storage available" => "Espaço de armazenamento insuficiente",
"Attempt to upload blacklisted file:" => "Tentativa de fazer o envio do arquivo de lista negra:",
"Error uploading contacts to storage." => "Erro enviando contatos para armazenamento.",
"Error moving file to imports folder." => "Erro ao mover arquivo para a pasta de importações.",
"You do not have permissions to import into this address book." => "Você não tem permissão para importar para este livro de endereços.",
"File name missing from request." => "Nome do arquivo ausente da requisição.",
"Progress key missing from request." => "Chave de progresso faltando no pedido.",
"Attempt to access blacklisted file:" => "Tentativa de acesso ao arquivo de lista negra:",
"No key is given." => "Nenhuma chave foi fornecida.",
"No value is given." => "Nenhum valor foi fornecido.",
"Could not set preference: " => "Não foi possível definir preferência:",
"Contact" => "Contato",
"Other" => "Outro",
"HomePage" => "Página Inicial",
"Jabber" => "Jabber",
"Internet call" => "Chamada da Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Trabalho",
"Home" => "Home",
"Mobile" => "Móvel",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensagem",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Família",
"Enable LDAP Backend" => "Ativar Backend LDAP",
"Enable LDAP backend for the contacts application" => "Ativar backend para o aplicativo de contatos LDAP",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Aviso: LDAP Backend está em modo beta, use com precauções",
"New contact" => "Novo contato",
"Group name" => "Nome do grupo",
"New group" => "Novo grupo",
"Address books" => "Livros de Endereços",
"Display name" => "Nome de exibição",
"Add Address Book" => "Adicionar Livro de Endereço",
"Add LDAP Address Book" => "Adicionar Livro de Endereços LDAP",
"Automatic format" => "Formato automático",
"Select file..." => "Selecionar arquivo...",
"(De-)select all" => "(De)selecionar tudo",
"Sort order" => "Ordenar",
"First- Lastname" => "Nome- Sobrenome",
"Last-, Firstname" => "Sobrenome-, Nome",
"Delete" => "Excluir",
"Groups" => "Grupos",
"Download" => "Baixar",
"Merge" => "Mesclar",
"Email" => "E-mail",
"Phone" => "Telefone",
"Address" => "Endereço",
"Group" => "Grupo",
"Keyboard shortcuts" => "Atalhos do teclado",
"Navigation" => "Navegação",
"Next contact in list" => "Próximo contato na lista",
"Previous contact in list" => "Contato anterior na lista",
"Expand/collapse current addressbook" => "Expandir/recolher agenda atual",
"Next addressbook" => "Próxima agenda",
"Previous addressbook" => "Agenda anterior",
"Actions" => "Ações",
"Refresh contacts list" => "Atualizar lista de contatos",
"Add new contact" => "Adicionar novo contato",
"Add new addressbook" => "Adicionar nova agenda",
"Delete current contact" => "Remover contato atual",
"You have no contacts in your address book or your address book is disabled." => "Não existe nenhum contato em seu livro de endereço ou seu livro de endereços está desabilitado.",
"Add a new contact or import existing contacts from a VCF file." => "Adicionar um novo contato ou importe contatos existentes de um arquivo VCF.",
"Which contact should the data be merged into?" => "Quais os dados de contato que devem ser incorporados?",
"Delete the other(s) after successful merge?" => "Eliminar os outros após o sucesso da mesclagem?",
"Compose mail" => "Escrever e-mail",
"Delete current photo" => "Deletar imagem atual",
"Edit current photo" => "Editar imagem atual",
"Upload new photo" => "Enviar nova foto",
"Select photo from Files" => "Selecionar foto dos Arquivos",
"Favorite" => "Favorito",
"Name" => "Nome",
"First name" => "Primeiro nome",
"Additional names" => "Nomes adicionais",
"Last name" => "Sobrenome",
"Address book" => "Livro de endereços",
"Nickname" => "Apelido",
"Title" => "Título",
"Organization" => "Organização",
"Birthday" => "Aniversário",
"Website" => "Website",
"Instant messaging" => "Mensagem instantânea",
"Notes go here..." => "Observações aqui...",
"Add field..." => "Adicionar um campo...",
"Instant Messaging" => "Mensagem Instantânea",
"Note" => "Nota",
"Web site" => "Web site",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor, especifique um email válido.",
"someone@example.com" => "alguem@exemplo.com",
"Mail to address" => "Enviar email para o endereço",
"Delete email address" => "Remover endereço de email",
"Enter phone number" => "Digite um número de telefone",
"Go to web site" => "Ir para web site",
"View on map" => "Visualizar no mapa",
"Street address" => "Endereço da rua",
"Postal code" => "Código postal",
"City" => "Cidade",
"State or province" => "Estado ou província",
"Country" => "País",
"Instant Messenger" => "Mensageiro Instantâneo",
"Active" => "Ativo",
"Share" => "Compartilhar",
"Export" => "Exportar",
"CardDAV link" => "Link CardDAV",
"Edit" => "Editar",
"Addressbook URI" => "Livro de endereços URI",
"URI" => "URI",
"Description" => "Descrição",
"LDAP URL" => "URL LDAP",
"Anonymous" => "Anônimo",
"Read-only" => "Somente-Leitura",
"Read-Only" => "Somente-Leitura",
"User" => "Usuário",
"Password" => "Senha",
"Page size" => "Tamanho da página",
"Base DN for search" => "DN de base para pesquisa",
"Base DN" => "DN Base",
"Search filter" => "Filtro de pesquisa",
"Filter" => "Filtro",
"Base DN for modification" => "DN de base para a modificação",
"Base DN modification" => "Modificação DN Base",
"Connector" => "Conector",
"Connector value (Better use external editor and copy/paste)" => "Valor do Conector (melhor usar o editor externo e copiar/colar)",
"Copy from (Warning, replaces current custom value)" => "Copiar de (Atenção, substitui valor personalizado atual)"
);
